@@ -105,15 +105,6 @@ extern crate alloc;
 #[cfg(feature = "std")]
 extern crate std as alloc;
 
-#[cfg(feature = "std")]
-#[macro_use]
-extern crate core;
-
-#[cfg(test)]
-extern crate assert_matches;
-#[cfg(test)]
-extern crate wabt;
-
 use alloc::{
     boxed::Box,
     string::{String, ToString},
@@ -126,9 +117,6 @@ use std::error;
 #[cfg(not(feature = "std"))]
 extern crate libm;
 
-extern crate num_rational;
-extern crate num_traits;
-
 /// Error type which can be thrown by wasm code or by host environment.
 ///
 /// Under some conditions, wasm execution may produce a `Trap`, which immediately aborts execution.
