@@ -10,11 +10,11 @@ use core::{
 };
 use parity_wasm::elements::ResizableLimits;
 
-#[cfg(all(unix, not(feature = "vec_memory")))]
+#[cfg(all(feature = "virtual_memory", target_pointer_width = "64"))]
 #[path = "mmap_bytebuf.rs"]
 mod bytebuf;
 
-#[cfg(any(not(unix), feature = "vec_memory"))]
+#[cfg(not(all(feature = "virtual_memory", target_pointer_width = "64")))]
 #[path = "vec_bytebuf.rs"]
 mod bytebuf;
 
@@ -117,7 +117,6 @@ impl MemoryInstance {
     /// [`LINEAR_MEMORY_PAGE_SIZE`]: constant.LINEAR_MEMORY_PAGE_SIZE.html
     pub fn alloc(initial: Pages, maximum: Option<Pages>) -> Result<MemoryRef, Error> {
         {
-            use core::convert::TryInto;
             let initial_u32: u32 = initial.0.try_into().map_err(|_| {
                 Error::Memory(format!("initial ({}) can't be coerced to u32", initial.0))
             })?;
@@ -210,6 +209,7 @@ impl MemoryInstance {
     /// If you can provide a mutable slice you can use [`get_into`].
     ///
     /// [`get_into`]: #method.get_into
+    #[deprecated(since = "0.10.0", note = "use get_into or get_value method instead")]
     pub fn get(&self, offset: u32, size: usize) -> Result<Vec<u8>, Error> {
         let mut buffer = self.buffer.borrow_mut();
         let region = self.checked_region(&mut buffer, offset as usize, size)?;
@@ -523,6 +523,7 @@ impl MemoryInstance {
     ///
     /// [`get`]: #method.get
     /// [`set`]: #method.set
+    /// [`copy`]: #method.copy
     pub fn with_direct_access_mut<R, F: FnOnce(&mut [u8]) -> R>(&self, f: F) -> R {
         let mut buf = self.buffer.borrow_mut();
         f(buf.as_slice_mut())
@@ -558,6 +559,7 @@ impl MemoryInstance {
     ///
     /// [`get`]: #method.get
     /// [`set`]: #method.set
+    /// [`copy`]: #method.copy
     #[allow(clippy::needless_lifetimes)]
     pub fn direct_access_mut<'a>(&'a self) -> impl AsMut<[u8]> + 'a {
         struct Buffer<'a>(RefMut<'a, ByteBuf>);
@@ -623,11 +625,23 @@ mod tests {
         mem
     }
 
+    fn get_into_vec(mem: &MemoryInstance, offset: u32, size: usize) -> Vec<u8> {
+        let mut buffer = vec![0x00; size];
+        mem.get_into(offset, &mut buffer[..])
+            .unwrap_or_else(|error| {
+                panic!(
+                    "failed to retrieve data from linear memory at offset {} with size {}: {}",
+                    offset, size, error
+                )
+            });
+        buffer
+    }
+
     #[test]
     fn copy_overlaps_1() {
         let mem = create_memory(&[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]);
         mem.copy(0, 4, 6).expect("Successfully copy the elements");
-        let result = mem.get(0, 10).expect("Successfully retrieve the result");
+        let result = get_into_vec(&mem, 0, 10);
         assert_eq!(result, &[0, 1, 2, 3, 0, 1, 2, 3, 4, 5]);
     }
 
@@ -635,7 +649,7 @@ mod tests {
     fn copy_overlaps_2() {
         let mem = create_memory(&[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]);
         mem.copy(4, 0, 6).expect("Successfully copy the elements");
-        let result = mem.get(0, 10).expect("Successfully retrieve the result");
+        let result = get_into_vec(&mem, 0, 10);
         assert_eq!(result, &[4, 5, 6, 7, 8, 9, 6, 7, 8, 9]);
     }
 
@@ -644,7 +658,7 @@ mod tests {
         let mem = create_memory(&[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]);
         mem.copy_nonoverlapping(0, 10, 10)
             .expect("Successfully copy the elements");
-        let result = mem.get(10, 10).expect("Successfully retrieve the result");
+        let result = get_into_vec(&mem, 10, 10);
         assert_eq!(result, &[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]);
     }
 
@@ -677,9 +691,9 @@ mod tests {
 
         MemoryInstance::transfer(&src, 4, &dst, 0, 3).unwrap();
 
-        assert_eq!(src.get(0, 10).unwrap(), &[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]);
+        assert_eq!(get_into_vec(&src, 0, 10), &[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]);
         assert_eq!(
-            dst.get(0, 10).unwrap(),
+            get_into_vec(&dst, 0, 10),
             &[4, 5, 6, 13, 14, 15, 16, 17, 18, 19]
         );
     }
@@ -690,7 +704,7 @@ mod tests {
 
         MemoryInstance::transfer(&src, 4, &src, 0, 3).unwrap();
 
-        assert_eq!(src.get(0, 10).unwrap(), &[4, 5, 6, 3, 4, 5, 6, 7, 8, 9]);
+        assert_eq!(get_into_vec(&src, 0, 10), &[4, 5, 6, 3, 4, 5, 6, 7, 8, 9]);
     }
 
     #[test]
@@ -699,7 +713,7 @@ mod tests {
         assert!(MemoryInstance::transfer(&src, 65535, &src, 0, 3).is_err());
 
         // Check that memories content left untouched
-        assert_eq!(src.get(0, 10).unwrap(), &[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]);
+        assert_eq!(get_into_vec(&src, 0, 10), &[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]);
     }
 
     #[test]
@@ -712,9 +726,9 @@ mod tests {
         assert!(MemoryInstance::transfer(&src, 65535, &dst, 0, 3).is_err());
 
         // Check that memories content left untouched
-        assert_eq!(src.get(0, 10).unwrap(), &[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]);
+        assert_eq!(get_into_vec(&src, 0, 10), &[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]);
         assert_eq!(
-            dst.get(0, 10).unwrap(),
+            get_into_vec(&dst, 0, 10),
             &[10, 11, 12, 13, 14, 15, 16, 17, 18, 19]
         );
     }
@@ -724,7 +738,7 @@ mod tests {
         let mem = create_memory(&[0, 1, 2, 3, 4, 5, 6, 7, 8, 9]);
         mem.clear(0, 0x4A, 10)
             .expect("To successfully clear the memory");
-        let result = mem.get(0, 10).expect("To successfully retrieve the result");
+        let result = get_into_vec(&mem, 0, 10);
         assert_eq!(result, &[0x4A; 10]);
     }
 
